#! /bin/bash


##the working directory, change this if you in diff place
#file_dir='/home/wjkw1/RESEARCH_2018-19/bash_test/'

##names of the files
#jar_filename='testing_jar.jar'
#log_filename='loggingtest.log'

##log file and jar file compilation
#jar_file=$file_dir$jar_filename
#log_file=$file_dir$log_filename

#echo "Executing... $jar_filename"
#java -jar $jar_file $log_file
#echo "Finished executing $jar_filename"

###################################
macronlogs_folder=/home/wjkw1/comp520/MacroniserLogs/tmp #/home/wjkw1/comp520/MacroniserLogs/logs #/Scratch/wjkw1/macron-restoration/web/logs
#macronLogToDBjar=
exec_folder=/home/wjkw1/IdeaProjects/LogFileExtraction/out/production/LogFileExtraction
processed_folder=/Scratch/wjkw1/processed #/Scratch/wjkw1/macron-restoration/processed
reprocess_folder=/Scratch/wjkw1/reprocess #/Scratch/wjkw1/macron-restoration/reprocess
errfile=/Scratch/wjkw1/macronLogToDB.err #/Scratch/wjkw1/macron-restoration/macronLogToDB.err
email_address=wilsonw9378@gmail.com #tetaka1@gmail.com
jars_folder=/Scratch/wjkw1/mysql-connector-java-8.0.14 #/Scratch/wjkw1/macron-restoration/web/WEB-INF/lib
mysqlprops_folder=/Scratch/wjkw1/classes #/Scratch/wjkw1/macron-restoration/web/WEB-INF/classes

echo ""
echo "In script $0 to process macron.log.* files"
echo "  Note that any logfile named exactly 'macron.log' (instead of matching macron.log.*) will not be processed"

# get rid of any old error files
if [ -e $errfile ] ; then
    rm $errfile
fi

if [ ! -d $macronlogs_folder ] ; then
    echo "$macronlogs_folder does not exist. Terminating script $0." >> $errfile
fi

# create these directories iff they don't exist
mkdir -p $processed_folder
mkdir -p $reprocess_folder


# "Bash does carry out filename expansion [1] -- a process known as globbing"
# https://www.tldp.org/LDP/abs/html/globbingref.html
IFS="$(printf '\n\t')"   # Remove space.

#  Correct glob use:
#  Always use for-loop, prefix glob, check if exists file.
for logfile in $macronlogs_folder/macron.log.* ; do         # Use ./* ... NEVER bare * [EDIT: if in current folder?]
    if [ -e "$logfile" ] ; then   # Check whether file exists.
      echo "****** processing $logfile"      

      # https://askubuntu.com/questions/625224/how-to-redirect-stderr-to-a-file

      echo "Running command:"
      echo "   java -cp .:$exec_folder:$jars_folder/mysql-connector-java-8.0.14.jar:$mysqlprops_folder util.MacroniserLogFileProcessor $logfile 2>> $errfile"
      echo ""
      java -cp .:$exec_folder:$jars_folder/mysql-connector-java-8.0.14.jar:$mysqlprops_folder util.MacroniserLogFileProcessor $logfile 2>> $errfile
      
      
      # The above returns 0 on success, -1 on failure
      # if 0, then move $logfile to processed_folder
      # and if -1, move to reprocess_folder
      # https://askubuntu.com/questions/324423/how-to-access-the-last-return-value-in-bash
      # https://www.tldp.org/LDP/abs/html/comparison-ops.html
      result=$?
      if [ "$result" -eq "0" ]; then
	  echo "Done processing $logfile, moving to $processed_folder"
	  mv $logfile "$processed_folder/."
      else
	  echo "Need to reprocess $logfile, moving to $reprocess_folder" >> $errfile
	  mv $logfile "$reprocess_folder/."
      fi
  fi
done

IFS="$(printf '\n\t')"   # Remove space.

#  Correct glob use:
#  Always use for-loop, prefix glob, check if exists file.
#for file in ./macron.log.* ; do         # Use ./* ... NEVER bare *
#  if [ -e "$file" ] ; then   # Check whether file exists.
#     echo "$file"
#  fi
#done

echo "Finished processing macron.log.* files"
echo ""

# If error file exists and has non-zero size, send email
# https://stackoverflow.com/questions/30080997/if-file-is-exists-and-is-not-empty-always-gives-me-the-false-value
if [ -s $errfile ] ; then    
    # send email with contents of error file
    echo "cat $errfile | mail -s 'Macron.log to DB cron failure output' $email_address"
    # TODO: uncomment on a machine that's allowed to email
    #cat $errfile | mail -s 'Macron.log to DB cron failure output' $email_address

    
    #echo "Supposed to have sent MAIL by now."
fi


# Cronjob: https://stackoverflow.com/questions/8938120/how-to-run-cron-once-daily-at-10pm

# In an x-term, on a machine:
# 
